__version__ = '0.21.3'
version_code_sstc_core = __version__
version_data_processing = '2.0-2024'
version_platform_flags = '0.5-2024'
version_qflag = '0.3-2024'
version_schema_platform_phenocams = '0.6-2024'
version_phenocam_app = '0.2.0'
